# Jalil Varela Manjarres

### En esta libreta se aprende a trabajar con imagenes en python, mediante la libreria de numpy, para ello, se reconoce la forma como se almacenan las imagenes y se entiende el funcionamiento de cada canal que compone a la imagen(RGB), ademas se trabaja con un problema de optimizacion, en el cual se ajutan funciones gausianas a muchas estrellas para asi determinar el FWHM, por tal motivo se trata de buscar la mejor forma de escoger las estrellas mediante un procedimiento semi automatico.


```python
#Librerias que se van a utilizar

import numpy as np
import matplotlib.pyplot as plt
import statistics as stat
#funcion para optimizar
from scipy.optimize import leastsq
```

La imagen con la que se va a trabajar va a almecenar en la variable -cielo-


```python
cielo = plt.imread('data/zapatocaImage.jpeg')
plt.imshow(cielo[:,:,:], cmap='gray')
```




    <matplotlib.image.AxesImage at 0x7f3ff8700ac8>




    
![png](Entrega_files/Entrega_3_1.png)
    


- El  que se almacena en cielo guarda la imagen en 3 matrices(canales) correspondientes a la informacion del color rojo, verde y azul, en la siguiente forma.
<vr>


- cielo[:,:,0]#rojo

- cielo[:,:,1]#verde

- cielo[:,:,2]#azul


- El comando Imshow lee estas 3 matrices e imprime la imagen, en caso de pasarle solo una array de 2 dimensiones, este leera la matriz en la escala que crea conveniente.




# Metodos para pasar a escala de grises

## Metodo 1

El primer metodo consiste en promediar estas tres matrices y trabajar solo con un arreglo en dos dimensiones.  para trabajar mas facilmente en la escala de 0 a 1, por lo general cada los numeros van de 0 a 255 en intensidad.


```python
#Se promedia las tres matrices de colores, casilla por casilla,
#seproduce una unica matriz promediada y se normalizan los valores(por lo general la escala
# va de 0 a 255)
img=np.mean(cielo,axis=2)/255
#Se debe espificar escala de grises debido a que imshow rescala automaticamente la escala que cre mas conveniente
plt.imshow(img, cmap='gray')

```




    <matplotlib.image.AxesImage at 0x7f4d70859358>




    
![png](Entrega_files/Entrega_7_1.png)
    


## Metodo 2
El segundo metodo ajusta una escala en la que el el ojo humano asimila mejor la escala de grises, para ello pondera la contribucion de los diferentes canalanes, el rojo, el verde y el azul y se utiliza la compresion Gamma.

la referencia utilizada y la forma en que se deben ponderar se especifica en la siguiente referencia [https://e2eml.school/convert_rgb_to_grayscale.html]


```python
#Se trabaa sobre una copia de la imagen original para no modificarla
cielomod=np.copy(cielo)/255

#Se se modifican los valores de las matrices de colores de acuerdo a la compresion Gamma

#Rojo
cielomod[:,:,0][cielomod[:,:,0]<=0.04055]=cielomod[:,:,0][cielomod[:,:,0]<=0.04055]/12.92
cielomod[:,:,0][cielomod[:,:,0]>0.04055]=((cielomod[:,:,0][cielomod[:,:,0]>0.04055]+0.055)/(1.055))**2.4

#Verde
cielomod[:,:,1][cielomod[:,:,1]<=0.04055]=cielomod[:,:,1][cielomod[:,:,1]<=0.04055]/12.92
cielomod[:,:,1][cielomod[:,:,1]>0.04055]=((cielomod[:,:,1][cielomod[:,:,1]>0.04055]+0.055)/(1.055))**2.4


#Azul
cielomod[:,:,2][cielomod[:,:,2]<=0.04055]=cielomod[:,:,2][cielomod[:,:,2]<=0.04055]/12.92
cielomod[:,:,2][cielomod[:,:,2]>0.04055]=((cielomod[:,:,2][cielomod[:,:,2]>0.04055]+0.055)/(1.055))**2.4


```


```python
#Se ponderan los valores para que la luminosidad se mas acorde a la del ojo humano
cielomod[:,:,0] =0.2126*cielomod[:,:,0] #rojo
cielomod[:,:,1] =0.7152*cielomod[:,:,1] #verde
cielomod[:,:,2] =0.0722*cielomod[:,:,2] #Azul

#Se suman los valores ponderados
cielomod[:,:,0]=cielomod[:,:,0]+cielomod[:,:,1]+cielomod[:,:,2]

#Se pinta la matriz correspondiente a la suma ponderada, especificando la escala de grises
plt.imshow(cielomod[:,:,0],cmap='gray')
```




    <matplotlib.image.AxesImage at 0x7f4d9699d748>




    
![png](Entrega_files/Entrega_10_1.png)
    


# Comparación


```python
fig, (ax1, ax2)=plt.subplots(1,2, figsize=(20, 10))
ax1.imshow(cielomod[:,:,0],cmap='gray')
ax1.set_title('Metodo2')
ax2.imshow(img,cmap='gray')
ax2.set_title('Metodo1')
```




    Text(0.5, 1.0, 'Metodo1')




    
![png](Entrega_files/Entrega_12_1.png)
    


# Optimizacion del ancho de una sola estrella con una gaussiana



```python
#Se recorta una estrella y se usan 25x25 pixeles de tamaño
plt.imshow(img[540:565,650:675],cmap='gray')
#Se almacena la estrella
estrella=np.copy(img[540:565,650:675])
```


    
![png](Entrega_files/Entrega_14_0.png)
    



```python
#Se crea una gaussiana 
def gauss2D(p,x,y):
    
#    donde p son los parametros que se busca optimizar

    exponente = -((x-p[0])**2 + (y-p[1])**2) / (2*p[2]**2)
    z = p[3] * np.exp(exponente) + p[4]
    return z

```


```python
#Se deine el error que devuelve un array en 1D!!!!
def Error(p,x,y,z):
    ymodel=gauss2D(p,x,y)
#    ymodel=gaussvec(p,x,y)
    error=ymodel-z
    return error.reshape(-1)

```


```python
#Se toman los parametros iniciales

# x0 y0 c, a , b. (revisar como se definen los parametros de la gaussiana para ver el significado)
p0=[12,12,10,1,0]

#Se crea un grilla de 25x25, correspondiente a las posiciones de cada pixel- correspondera al argumento de la funcion
x=np.arange(0,25,1)
y=np.arange(0,25,1)
yy,xx=np.meshgrid(x,y)

# Se realiza la optimizacion por minimos cuadrados
best,suss=leastsq(Error,p0,args=(xx,yy,estrella))
```


```python
#Se verifica que se ajusto correctamente la gaussiana

fig, (ax1, ax2)=plt.subplots(1,2,figsize=(10,6))

ax1.imshow(gauss2D(best,xx,yy),cmap='gray')
ax1.set_title('Gaussiana')

ax2.imshow(estrella,cmap='gray')
ax2.set_title('Imagen')


```




    Text(0.5, 1.0, 'Imagen')




    
![png](Entrega_files/Entrega_18_1.png)
    


# ¡Generalizacion del metodo a muchas estrellas!

Lo primero es definir una forma rapida de recortar las estrellas, en funcion de una cota minima de la luminosidad, el tamaño del recuadro que queremos y la imagen que se va a tomar. Esta funcion se llamara con una posicion que se le asignara a cada elemento que ella considere como estrella, y los parametros de luminosidad, tamaño y la imagen a utilizar y devuelve el array correspondiente a la estrella recortada, la posicion central de la estrella y la imagen recortada.


```python
#Buscamos candidatas para las estrellas 
def buscarestrellas(i,tam,luminosidad,img):
    x=np.where(img > luminosidad)
#Se recorta una estrella y se usan 25x25 pixeles de anchura
    print(f"posicion de la estrella: y,x={x[0][i],x[1][i]}")
    print(f"tamaño: {np.shape(img[x[0][i]-tam:x[0][i]+tam,x[1][i]-tam:x[1][i]+tam])}")
    print(f"numero de candidtas: {np.shape(x)[1]}")
    
    return img[x[0][i]-tam:x[0][i]+tam,x[1][i]-tam:x[1][i]+tam],x , plt.imshow(img[x[0][i]-tam:x[0][i]+tam,x[1][i]-tam:x[1][i]+tam],cmap='gray')

x=buscarestrellas(1,10,0.9,img)[2]

```

    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_20_1.png)
    


Lo siguiente es definir una forma en la cual podamos **testestear manualmente** si los recortes tomados de la imagen son unos buenos candidatos para las estrellas que queremos adopatar, de nuevo tomando el tamaño, la luminosidad y la imagen que se quieren tener para devolver un diccionario con las estrellas que son buenas candidatas


```python
#Revision de las estrellas 

def rev(tam,luminosidad,img):
    Estrellas={}
    i=0
    
    #Corre sobre el numero de estrellas que se tomaron como candidatas
    j=0
    N=len(buscarestrellas(i,tam,luminosidad,img)[1][1])
    
    # Se crea un loop que corra que en cada interaccion nos permita decidir si la estrella es una buena candidatta
    for i in np.arange(N):
        
        #Se muestra la candida a ser estrella
        buscarestrellas(i,tam,luminosidad,img)[2]
        
        plt.show()
        
        
        respuesta=input('¿es un buena candidata?, responda con s/n o t si desea terminar')
        
        if respuesta=='s':
            
            Estrellas[f'e{j}']=buscarestrellas(i,tam,luminosidad,img)[0]
            j=j+1
            
        #Se crea una opcion para cortar el loop si se desea y almacenar los datos actuales
        elif respuesta =='t':
            # Se pinta el numero de estrellas que se tomaron
            print(f'Se tomaron {j} estrellas')
            
            #Se retorna las estrellas almacenadas
            return Estrellas
        
        else: 

            i=i+1
            plt.show()
        print(f'Se tomaron {j} estrellas')
    return Estrellas
        

Estrellas=rev(10,0.9,img)

```

    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 178
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_1.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 1 estrellas
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_3.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 2 estrellas
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_5.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(54, 990)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_7.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_9.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_11.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 4 estrellas
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_13.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 4 estrellas
    posicion de la estrella: y,x=(86, 528)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_22_15.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminart
    Se tomaron 4 estrellas


Ahora la idea e optimizar las estrellas que son unas buenas candidatas, para ello se desarrolla una funcion que tome como argumento el diccionario correspondiente a las candidatas y la funcion de Error que se va a utilizar para optimizar, la idea es que devuelve una matriz con las filas siendo los parametros optimizados de cada estrella


```python

def datoses(Estrellas,Error):
    es=np.array([[0,0,0,0,0],[0,0,0,0,0]])
    es=np.delete(es, (0,1), axis=0)
    
    # x0 y0 c, a , b
    p0=[10,10,2,1,0]

    #Se crea un grilla de 25x25, correspondiente a las posiciones de cada pixel
    x=np.arange(0,20,1)
    y=np.arange(0,20,1)
    yy,xx=np.meshgrid(x,y)
    for i in Estrellas.keys():
        es=np.append(es,[leastsq(Error,p0,args=(xx,yy,Estrellas[i]))[0]],axis=0)
    
    return es    
es=datoses(Estrellas,Error)
# Se realiza la optimizacion por minimos cuadrados
#best,suss=leastsq(Error,p0,args=(xx,yy,estrella))

```

**Funcion opcional que compara la imagen optimizada con la original, para verificar si los ajustes son buenos**


```python
def verificacion(es,Estrellas):
    j=0
    m=Estrellas.keys()
    for i in m:
    #Se verifica que se ajusto correctamente la gaussiana
        fig, (ax1, ax2)=plt.subplots(1,2,figsize=(10,6))

        ax1.imshow(gauss2D(es[j],xx,yy),cmap='gray')
        ax1.set_title('Gaussiana')

        ax2.imshow(Estrellas[i],cmap='gray')
        
        ax2.set_title('Imagen')
        plt.show()
        j=j+1
        
verificacion(es,Estrellas)
  
```


    
![png](Entrega_files/Entrega_26_0.png)
    



    
![png](Entrega_files/Entrega_26_1.png)
    



    
![png](Entrega_files/Entrega_26_2.png)
    



    
![png](Entrega_files/Entrega_26_3.png)
    



    
![png](Entrega_files/Entrega_26_4.png)
    



    
![png](Entrega_files/Entrega_26_5.png)
    



    
![png](Entrega_files/Entrega_26_6.png)
    



    
![png](Entrega_files/Entrega_26_7.png)
    



    
![png](Entrega_files/Entrega_26_8.png)
    



    
![png](Entrega_files/Entrega_26_9.png)
    



    
![png](Entrega_files/Entrega_26_10.png)
    



    
![png](Entrega_files/Entrega_26_11.png)
    



    
![png](Entrega_files/Entrega_26_12.png)
    



    
![png](Entrega_files/Entrega_26_13.png)
    



    
![png](Entrega_files/Entrega_26_14.png)
    



    
![png](Entrega_files/Entrega_26_15.png)
    



    
![png](Entrega_files/Entrega_26_16.png)
    



    
![png](Entrega_files/Entrega_26_17.png)
    



    
![png](Entrega_files/Entrega_26_18.png)
    



    
![png](Entrega_files/Entrega_26_19.png)
    



    
![png](Entrega_files/Entrega_26_20.png)
    



    
![png](Entrega_files/Entrega_26_21.png)
    



    
![png](Entrega_files/Entrega_26_22.png)
    



    
![png](Entrega_files/Entrega_26_23.png)
    



    
![png](Entrega_files/Entrega_26_24.png)
    



    
![png](Entrega_files/Entrega_26_25.png)
    



    
![png](Entrega_files/Entrega_26_26.png)
    



    
![png](Entrega_files/Entrega_26_27.png)
    



    
![png](Entrega_files/Entrega_26_28.png)
    



    
![png](Entrega_files/Entrega_26_29.png)
    



    
![png](Entrega_files/Entrega_26_30.png)
    



    
![png](Entrega_files/Entrega_26_31.png)
    



    
![png](Entrega_files/Entrega_26_32.png)
    



    
![png](Entrega_files/Entrega_26_33.png)
    



    
![png](Entrega_files/Entrega_26_34.png)
    



    
![png](Entrega_files/Entrega_26_35.png)
    



    
![png](Entrega_files/Entrega_26_36.png)
    



    
![png](Entrega_files/Entrega_26_37.png)
    



    
![png](Entrega_files/Entrega_26_38.png)
    



    
![png](Entrega_files/Entrega_26_39.png)
    



    
![png](Entrega_files/Entrega_26_40.png)
    



    
![png](Entrega_files/Entrega_26_41.png)
    



    
![png](Entrega_files/Entrega_26_42.png)
    



    
![png](Entrega_files/Entrega_26_43.png)
    



    
![png](Entrega_files/Entrega_26_44.png)
    



    
![png](Entrega_files/Entrega_26_45.png)
    



    
![png](Entrega_files/Entrega_26_46.png)
    



    
![png](Entrega_files/Entrega_26_47.png)
    



    
![png](Entrega_files/Entrega_26_48.png)
    



    
![png](Entrega_files/Entrega_26_49.png)
    



    
![png](Entrega_files/Entrega_26_50.png)
    



    
![png](Entrega_files/Entrega_26_51.png)
    



    
![png](Entrega_files/Entrega_26_52.png)
    


Lo siguiente es crear un funcion que me imprima todas las **estadisticas** deseadas, en este caso, son la media, la mediana, la moda, la desviacion estandar y un histograma, toma la imagen como argumento, el tamaño, la luminosidad y Error que se esta utlizando para optimizarlas.


```python
# Crear una funcion que me devuelva media mediana moda e histograma

def funcestrellas(img,tam,lum,Error):
    #Se almacenan las candidatas en un diccionario
    Estrellas1=rev(tam,lum,img)
    #Se optimizan las candidatas
    es=datoses(Estrellas1,Error)
    
    # Se define el FWHM
    FWHM=(2*(2*np.log(2))**(1/2))*es[:,2]

    
    #Se encuentran las estadisticas y se imprimen
    media=np.mean(FWHM)
    mediana=np.median(FWHM)
    #le pasamos una llave de una funcion que devuelva cuantas veces se repite el numero en la lista
    #De los elementos que se van a ordenar se toma el que mas se repite
    moda=max(set(np.round(FWHM,2)), key=list(np.round(FWHM,2)).count)
#    FWHME= [round(FWHM[i],2) for i in np.arange(len(FWHM))]
#    moda=stat.mode(FWHME)
    desviacion=stat.stdev(FWHM)
    print(f'la media es: {media} ')
    print(f'la mediana es: {mediana} ')
    print(f'la moda es: {moda} ')
    print(f'la desviacion estandar es:{desviacion}')
    plt.hist(FWHM,bins=10, alpha=0.8, histtype='bar', ec='black')

```

# Ahora se aplicara esto para encontrar las multiples estadisticas para:

- la imagen en escala de grisis
- la imagen del canal rojo
- la imagen del canal verde
- la imagen del canal azul

# Escala de grisis


```python
#Imagen en escala de grisis
funcestrellas(img,10,0.95,Error)
```

    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 101
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_1.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 1 estrellas
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_3.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 2 estrellas
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_5.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_7.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 4 estrellas
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_9.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_11.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(128, 403)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_13.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(129, 403)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_15.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(133, 741)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_17.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(133, 741)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_19.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(244, 218)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_21.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_23.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(280, 1073)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_25.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(280, 1073)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 9 estrellas
    posicion de la estrella: y,x=(285, 892)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_27.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(285, 892)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(292, 601)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_29.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(292, 601)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 11 estrellas
    posicion de la estrella: y,x=(296, 309)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_31.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(296, 309)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 12 estrellas
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_33.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(305, 479)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_35.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(306, 478)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_37.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(306, 479)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_39.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(315, 626)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_41.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(315, 627)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_43.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(315, 628)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_45.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(316, 626)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_47.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(316, 627)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_49.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(316, 627)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(316, 628)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_51.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(317, 627)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_53.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(317, 628)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_55.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(320, 612)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_57.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(320, 612)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(326, 565)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_59.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(326, 565)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 16 estrellas
    posicion de la estrella: y,x=(331, 775)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_61.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(331, 775)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_63.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(339, 541)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_65.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_67.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(351, 547)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_69.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(352, 546)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_71.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(352, 547)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_73.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(352, 547)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(359, 587)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_75.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(359, 588)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_77.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(360, 592)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_79.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(360, 593)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_81.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(361, 592)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_83.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(363, 551)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_85.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(364, 551)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_87.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(379, 743)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_89.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(379, 743)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(380, 743)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_91.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(380, 743)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 21 estrellas
    posicion de la estrella: y,x=(383, 710)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_93.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(383, 710)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 22 estrellas
    posicion de la estrella: y,x=(398, 621)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_95.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(398, 621)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 23 estrellas
    posicion de la estrella: y,x=(399, 621)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_97.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(399, 621)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 24 estrellas
    posicion de la estrella: y,x=(399, 622)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_99.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(399, 622)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(441, 883)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_101.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(442, 883)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_103.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(461, 324)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_105.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(461, 324)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 26 estrellas
    posicion de la estrella: y,x=(462, 324)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_107.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(462, 324)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 27 estrellas
    posicion de la estrella: y,x=(500, 685)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_109.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 27 estrellas
    posicion de la estrella: y,x=(501, 685)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_111.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 27 estrellas
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_113.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(550, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_115.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(550, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_117.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(550, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_119.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(550, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_121.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(551, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_123.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(551, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_125.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(551, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_127.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(551, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_129.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(551, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_131.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(551, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_133.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(552, 659)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_135.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(552, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_137.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(552, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_139.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(552, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_141.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(552, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_143.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(552, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_145.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(552, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_147.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(553, 659)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_149.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(553, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_151.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(553, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_153.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(553, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_155.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(553, 662)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(553, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_157.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(553, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_159.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(553, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_161.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(554, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_163.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(554, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_165.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(554, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_167.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(554, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_169.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(554, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_171.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(554, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_173.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(555, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_175.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(555, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_177.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(555, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_179.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(555, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_181.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(555, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_183.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(555, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_185.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(556, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_187.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(556, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_189.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(602, 1144)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_191.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(602, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_193.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(602, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(603, 1144)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_195.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(603, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_197.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(604, 1144)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_199.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(604, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_31_201.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    la media es: 3.090835929405834 
    la mediana es: 2.4801048552775113 
    la moda es: 2.19 
    la desviacion estandar es:1.6763671769460615



    
![png](Entrega_files/Entrega_31_203.png)
    


# Para los canales de colores


```python
#Para las otras candidatas primero definimos los arrays que contengan solo la informacion de cada canal
rojo=np.copy(cielo)/255
rojo=rojo[:,:,0]

verde=np.copy(cielo)/255
verde=verde[:,:,1]

azul=np.copy(cielo)/255
azul=azul[:,:,2]
```

## Rojo


```python
funcestrellas(rojo,10,0.95,Error)
```

    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 178
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_1.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 1 estrellas
    posicion de la estrella: y,x=(34, 333)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_3.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(34, 333)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 2 estrellas
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_5.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_7.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 4 estrellas
    posicion de la estrella: y,x=(54, 990)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_9.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(54, 990)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_11.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_13.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_15.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(86, 528)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_17.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(86, 528)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(87, 632)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_19.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(87, 632)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 9 estrellas
    posicion de la estrella: y,x=(90, 862)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_21.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(90, 862)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(97, 325)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_23.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(97, 325)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 11 estrellas
    posicion de la estrella: y,x=(98, 318)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_25.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(98, 318)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 12 estrellas
    posicion de la estrella: y,x=(104, 410)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_27.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(104, 410)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(107, 386)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_29.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(118, 364)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_31.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(118, 364)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(127, 418)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_33.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(128, 403)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_35.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(129, 403)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_37.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(129, 404)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_39.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(132, 741)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_41.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(132, 741)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(132, 742)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_43.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(133, 741)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_45.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(133, 742)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_47.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(134, 863)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_49.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(134, 863)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 16 estrellas
    posicion de la estrella: y,x=(135, 863)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_51.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 16 estrellas
    posicion de la estrella: y,x=(147, 392)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_53.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 16 estrellas
    posicion de la estrella: y,x=(147, 393)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_55.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 16 estrellas
    posicion de la estrella: y,x=(147, 394)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_57.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(147, 394)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(148, 392)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_59.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(148, 393)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_61.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(148, 394)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_63.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(149, 393)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_65.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(149, 394)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_67.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(151, 659)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_69.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(151, 659)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(159, 399)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_71.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(167, 465)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_73.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(167, 465)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(193, 1022)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_75.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(193, 1022)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(207, 605)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_77.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(207, 605)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 21 estrellas
    posicion de la estrella: y,x=(211, 471)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_79.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(211, 471)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 22 estrellas
    posicion de la estrella: y,x=(213, 418)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_81.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(213, 418)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 23 estrellas
    posicion de la estrella: y,x=(214, 492)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_83.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(214, 492)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 24 estrellas
    posicion de la estrella: y,x=(215, 492)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_85.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(215, 492)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(221, 505)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_87.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(221, 505)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 26 estrellas
    posicion de la estrella: y,x=(222, 505)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_89.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(222, 505)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 27 estrellas
    posicion de la estrella: y,x=(231, 598)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_91.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(231, 598)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(242, 713)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_93.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(242, 713)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_95.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(243, 713)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_97.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(243, 713)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 31 estrellas
    posicion de la estrella: y,x=(244, 218)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_99.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(244, 218)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 32 estrellas
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_101.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 33 estrellas
    posicion de la estrella: y,x=(255, 951)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_103.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 33 estrellas
    posicion de la estrella: y,x=(263, 767)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_105.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(263, 767)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 34 estrellas
    posicion de la estrella: y,x=(270, 947)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_107.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(270, 947)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 35 estrellas
    posicion de la estrella: y,x=(280, 1073)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_109.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 35 estrellas
    posicion de la estrella: y,x=(285, 892)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_111.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 35 estrellas
    posicion de la estrella: y,x=(292, 601)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_113.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 35 estrellas
    posicion de la estrella: y,x=(296, 309)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_115.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 35 estrellas
    posicion de la estrella: y,x=(297, 309)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_117.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(297, 309)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 36 estrellas
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_119.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 37 estrellas
    posicion de la estrella: y,x=(305, 479)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_121.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 37 estrellas
    posicion de la estrella: y,x=(306, 478)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_123.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 37 estrellas
    posicion de la estrella: y,x=(306, 479)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_125.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 37 estrellas
    posicion de la estrella: y,x=(315, 627)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_127.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(315, 627)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 38 estrellas
    posicion de la estrella: y,x=(315, 628)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_129.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 38 estrellas
    posicion de la estrella: y,x=(316, 627)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_131.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 38 estrellas
    posicion de la estrella: y,x=(316, 628)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_133.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 38 estrellas
    posicion de la estrella: y,x=(320, 612)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_135.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(320, 612)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 39 estrellas
    posicion de la estrella: y,x=(321, 436)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_137.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 39 estrellas
    posicion de la estrella: y,x=(325, 565)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_139.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(325, 565)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 40 estrellas
    posicion de la estrella: y,x=(326, 565)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_141.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 40 estrellas
    posicion de la estrella: y,x=(327, 442)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_143.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 40 estrellas
    posicion de la estrella: y,x=(330, 775)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_145.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(330, 775)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 41 estrellas
    posicion de la estrella: y,x=(331, 775)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_147.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 41 estrellas
    posicion de la estrella: y,x=(332, 706)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_149.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(332, 706)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 42 estrellas
    posicion de la estrella: y,x=(332, 707)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_151.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 42 estrellas
    posicion de la estrella: y,x=(338, 540)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_153.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(338, 540)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 43 estrellas
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_155.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 43 estrellas
    posicion de la estrella: y,x=(339, 541)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_157.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 43 estrellas
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_159.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 44 estrellas
    posicion de la estrella: y,x=(351, 547)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_161.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 44 estrellas
    posicion de la estrella: y,x=(352, 546)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_163.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 44 estrellas
    posicion de la estrella: y,x=(352, 547)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_165.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 44 estrellas
    posicion de la estrella: y,x=(358, 587)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_167.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(358, 587)
    tamaño: (20, 20)
    numero de candidtas: 178
    Se tomaron 45 estrellas
    posicion de la estrella: y,x=(358, 588)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_169.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 45 estrellas
    posicion de la estrella: y,x=(359, 587)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_171.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 45 estrellas
    posicion de la estrella: y,x=(359, 588)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_173.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 45 estrellas
    posicion de la estrella: y,x=(360, 559)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_175.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 45 estrellas
    posicion de la estrella: y,x=(360, 592)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_177.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 45 estrellas
    posicion de la estrella: y,x=(360, 593)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_179.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 45 estrellas
    posicion de la estrella: y,x=(361, 592)
    tamaño: (20, 20)
    numero de candidtas: 178



    
![png](Entrega_files/Entrega_35_181.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminart
    Se tomaron 45 estrellas
    la media es: 2.3999494401300905 
    la mediana es: 2.1778332069619895 
    la moda es: 1.95 
    la desviacion estandar es:0.7999514607789977



    
![png](Entrega_files/Entrega_35_183.png)
    


## Azul


```python
funcestrellas(azul,10,0.95,Error)

```

    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 89
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_1.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 1 estrellas
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_3.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 2 estrellas
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_5.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(244, 217)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_7.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(244, 218)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_9.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_11.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 4 estrellas
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_13.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(305, 479)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_15.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(306, 478)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_17.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(306, 479)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_19.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(315, 626)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_21.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(315, 626)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(315, 627)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_23.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(315, 628)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_25.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(316, 626)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_27.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(316, 627)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_29.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(316, 628)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_31.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(317, 626)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_33.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(317, 627)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_35.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(317, 628)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_37.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_39.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_41.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(351, 547)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_43.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(352, 546)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_45.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(352, 547)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_47.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(359, 587)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_49.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(359, 588)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_51.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(360, 592)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_53.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(360, 593)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_55.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(361, 592)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_57.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(363, 551)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_59.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(363, 551)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 9 estrellas
    posicion de la estrella: y,x=(364, 551)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_61.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 9 estrellas
    posicion de la estrella: y,x=(399, 621)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_63.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(399, 621)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(442, 883)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_65.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(442, 883)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 11 estrellas
    posicion de la estrella: y,x=(461, 324)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_67.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(461, 324)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 12 estrellas
    posicion de la estrella: y,x=(462, 324)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_69.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 12 estrellas
    posicion de la estrella: y,x=(500, 685)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_71.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(500, 685)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_73.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(550, 660)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_75.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(550, 661)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_77.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(550, 662)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_79.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(550, 663)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_81.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(550, 663)
    tamaño: (20, 20)
    numero de candidtas: 89
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(550, 664)
    tamaño: (20, 20)
    numero de candidtas: 89



    
![png](Entrega_files/Entrega_37_83.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminart
    Se tomaron 15 estrellas
    la media es: 4.142137375301819 
    la mediana es: 3.5883241429318904 
    la moda es: 2.67 
    la desviacion estandar es:2.3610105224008944



    
![png](Entrega_files/Entrega_37_85.png)
    


## Verde


```python
funcestrellas(verde,10,0.95,Error)
```

    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 106
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_1.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 1 estrellas
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_3.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 2 estrellas
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_5.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_7.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 4 estrellas
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_9.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(128, 403)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_11.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(129, 403)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_13.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(133, 741)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_15.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(133, 741)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(147, 393)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_17.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(147, 393)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(148, 393)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_19.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(148, 394)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_21.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_23.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(244, 218)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_25.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_27.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 9 estrellas
    posicion de la estrella: y,x=(270, 947)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_29.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(270, 947)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(280, 1073)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_31.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(285, 892)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_33.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(285, 892)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 11 estrellas
    posicion de la estrella: y,x=(292, 601)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_35.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 11 estrellas
    posicion de la estrella: y,x=(296, 309)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_37.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(296, 309)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 12 estrellas
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_39.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(305, 479)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_41.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(306, 478)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_43.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(306, 479)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_45.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(315, 626)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_47.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(315, 626)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(315, 627)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_49.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(315, 628)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_51.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(316, 626)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_53.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(316, 627)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_55.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(316, 628)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_57.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(317, 627)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_59.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(317, 628)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_61.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(320, 612)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_63.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(320, 612)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(326, 565)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_65.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(326, 565)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 16 estrellas
    posicion de la estrella: y,x=(331, 775)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_67.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(331, 775)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_69.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(339, 541)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_71.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_73.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(351, 547)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_75.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(351, 547)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(352, 546)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_77.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(352, 547)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_79.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(359, 587)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_81.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(359, 588)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_83.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(360, 592)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_85.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(360, 593)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_87.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(361, 592)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_89.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(363, 551)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_91.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(363, 551)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 21 estrellas
    posicion de la estrella: y,x=(364, 551)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_93.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 21 estrellas
    posicion de la estrella: y,x=(376, 450)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_95.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 21 estrellas
    posicion de la estrella: y,x=(376, 451)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_97.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(376, 451)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 22 estrellas
    posicion de la estrella: y,x=(377, 450)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_99.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 22 estrellas
    posicion de la estrella: y,x=(377, 451)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_101.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 22 estrellas
    posicion de la estrella: y,x=(379, 743)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_103.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(379, 743)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 23 estrellas
    posicion de la estrella: y,x=(380, 743)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_105.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 23 estrellas
    posicion de la estrella: y,x=(383, 710)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_107.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(383, 710)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 24 estrellas
    posicion de la estrella: y,x=(398, 621)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_109.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(398, 621)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(399, 621)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_111.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(399, 622)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_113.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(442, 883)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_115.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(442, 883)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 26 estrellas
    posicion de la estrella: y,x=(461, 324)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_117.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 26 estrellas
    posicion de la estrella: y,x=(462, 324)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_119.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 26 estrellas
    posicion de la estrella: y,x=(500, 685)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_121.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(500, 685)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 27 estrellas
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_123.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(550, 661)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_125.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(550, 661)
    tamaño: (20, 20)
    numero de candidtas: 106
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(550, 662)
    tamaño: (20, 20)
    numero de candidtas: 106



    
![png](Entrega_files/Entrega_39_127.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminart
    Se tomaron 29 estrellas
    la media es: 3.384100135176864 
    la mediana es: 2.6055091704735083 
    la moda es: 2.59 
    la desviacion estandar es:1.895875941224526



    
![png](Entrega_files/Entrega_39_129.png)
    


# Modificacion para añadir la incertidumbre de la medida

La unica funcion que se debe ver modificada es la funcion de error, donde cada pixel ahora debe estar pesado por la incertidumbre(dividiendo), la incertidumbre de capa pixel la asociamos con la intensidad que recibe debido a que 

- Intensidad= numero fotone/tiempo
- flujo= Intensidad/Area

En este caso el area de cada pixel se toma como 1


```python
#Se debe modificar el error para que cada error tenga un peso dado por las incertidumbres

def Errormod(p,x,y,z):
    
    #incertidumbre de cada pixel
    sigma=np.sqrt(z)
    
    #funcion del modelo
    ymodel=gauss2D(p,x,y)
    
# se divide el error sobre la incertidumbre, de esta forma se puede tener en cuenta la incertidumbre
    error=(ymodel-z)/sigma
    return error.reshape(-1)

```

# Se puede evaluar la misma funcion ya encontrada, unicamente cambiandole la funcion de error, asi podemos encontrar todas las estrellas de nuevo incluyendo la incertidumbre

Para el caso de la imagen en escala de grises obtenemos


```python
funcestrellas(img,10,0.95,Errormod)
```

    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 101
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_1.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(20, 609)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 1 estrellas
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_3.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(42, 724)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 2 estrellas
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_5.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(46, 885)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 3 estrellas
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_7.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(54, 991)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 4 estrellas
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_9.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(56, 455)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 5 estrellas
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_11.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(76, 716)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 6 estrellas
    posicion de la estrella: y,x=(128, 403)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_13.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(128, 403)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(129, 403)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_15.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 7 estrellas
    posicion de la estrella: y,x=(133, 741)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_17.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(133, 741)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 8 estrellas
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_19.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(243, 218)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 9 estrellas
    posicion de la estrella: y,x=(244, 218)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_21.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 9 estrellas
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_23.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(254, 951)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(280, 1073)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_25.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(285, 892)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_27.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 10 estrellas
    posicion de la estrella: y,x=(292, 601)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_29.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(292, 601)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 11 estrellas
    posicion de la estrella: y,x=(296, 309)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_31.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(296, 309)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 12 estrellas
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_33.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(305, 478)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(305, 479)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_35.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(306, 478)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_37.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(306, 479)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_39.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 13 estrellas
    posicion de la estrella: y,x=(315, 626)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_41.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(315, 626)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(315, 627)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_43.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(315, 628)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_45.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(316, 626)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_47.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(316, 627)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_49.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 14 estrellas
    posicion de la estrella: y,x=(316, 628)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_51.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(316, 628)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(317, 627)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_53.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(317, 628)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_55.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(320, 612)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_57.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 15 estrellas
    posicion de la estrella: y,x=(326, 565)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_59.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(326, 565)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 16 estrellas
    posicion de la estrella: y,x=(331, 775)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_61.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(331, 775)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 17 estrellas
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_63.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(339, 540)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(339, 541)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_65.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 18 estrellas
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_67.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(351, 546)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 19 estrellas
    posicion de la estrella: y,x=(351, 547)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_69.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(351, 547)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(352, 546)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_71.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(352, 547)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_73.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(359, 587)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_75.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(359, 588)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_77.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(360, 592)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_79.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(360, 593)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_81.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(361, 592)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_83.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 20 estrellas
    posicion de la estrella: y,x=(363, 551)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_85.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(363, 551)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 21 estrellas
    posicion de la estrella: y,x=(364, 551)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_87.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 21 estrellas
    posicion de la estrella: y,x=(379, 743)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_89.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(379, 743)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 22 estrellas
    posicion de la estrella: y,x=(380, 743)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_91.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(380, 743)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 23 estrellas
    posicion de la estrella: y,x=(383, 710)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_93.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(383, 710)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 24 estrellas
    posicion de la estrella: y,x=(398, 621)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_95.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 24 estrellas
    posicion de la estrella: y,x=(399, 621)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_97.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 24 estrellas
    posicion de la estrella: y,x=(399, 622)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_99.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(399, 622)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 25 estrellas
    posicion de la estrella: y,x=(441, 883)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_101.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(441, 883)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 26 estrellas
    posicion de la estrella: y,x=(442, 883)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_103.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminarn
    Se tomaron 26 estrellas
    posicion de la estrella: y,x=(461, 324)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_105.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(461, 324)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 27 estrellas
    posicion de la estrella: y,x=(462, 324)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_107.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 27 estrellas
    posicion de la estrella: y,x=(500, 685)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_109.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(500, 685)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(501, 685)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_111.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 28 estrellas
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_113.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(523, 816)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(550, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_115.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(550, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_117.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(550, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_119.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(550, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_121.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(551, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_123.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(551, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_125.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(551, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_127.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(551, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_129.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(551, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_131.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(551, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_133.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(552, 659)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_135.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(552, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_137.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(552, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_139.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 29 estrellas
    posicion de la estrella: y,x=(552, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_141.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(552, 662)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(552, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_143.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(552, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_145.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(552, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_147.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(553, 659)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_149.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(553, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_151.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(553, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_153.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(553, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_155.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(553, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_157.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(553, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_159.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(553, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_161.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(554, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_163.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(554, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_165.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(554, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_167.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(554, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_169.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(554, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_171.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(554, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_173.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(555, 660)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_175.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(555, 661)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_177.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(555, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_179.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(555, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_181.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(555, 664)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_183.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(555, 665)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_185.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(556, 662)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_187.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(556, 663)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_189.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(602, 1144)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_191.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(602, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_193.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(603, 1144)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_195.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 30 estrellas
    posicion de la estrella: y,x=(603, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_197.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminars
    posicion de la estrella: y,x=(603, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101
    Se tomaron 31 estrellas
    posicion de la estrella: y,x=(604, 1144)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_199.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 31 estrellas
    posicion de la estrella: y,x=(604, 1145)
    tamaño: (20, 20)
    numero de candidtas: 101



    
![png](Entrega_files/Entrega_43_201.png)
    


    ¿es un buena candidata?, responda con s/n o t si desea terminar
    Se tomaron 31 estrellas
    la media es: 3.724336217975907 
    la mediana es: 2.6843598193292726 
    la moda es: 2.12 
    la desviacion estandar es:2.5394607774573585



    
![png](Entrega_files/Entrega_43_203.png)
    



```python
#Para guardar el notebook a .md
! jupyter nbconvert --to markdown Entrega.ipynb
```

    [NbConvertApp] Converting notebook Entrega.ipynb to markdown
    [NbConvertApp] Support files will be in Entrega_files/
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Making directory Entrega_files
    [NbConvertApp] Writing 150930 bytes to Entrega.md

